@@ -4,8 +4,6 @@ package config
 type FetchOptions struct {
 	// Concurrency is the maximum number of concurrent helm processes to run, 0 is unlimited
 	Concurrency int
-	// SkipDeps is the skip deps flag
-	SkipDeps bool
 	// OutputDir is the output directory
 	OutputDir string
 	// OutputDirTemplate is the go template to generate the path of output directory
@@ -36,11 +34,6 @@ func (c *FetchImpl) Concurrency() int {
 	return c.FetchOptions.Concurrency
 }
 
-// SkipDeps returns the skip deps
-func (c *FetchImpl) SkipDeps() bool {
-	return c.FetchOptions.SkipDeps
-}
-
 // OutputDir returns the args
 func (c *FetchImpl) OutputDir() string {
 	return c.FetchOptions.OutputDir
