@@ -519,8 +519,8 @@ func (helm *execer) ChartPull(chart string, path string, flags ...string) error
 	if helmVersionConstraint.Check(helm.version) {
 		// in the 3.7.0 version, the chart pull has been replaced with helm pull
 		// https://github.com/helm/helm/releases/tag/v3.7.0
-		ociChartURL, ociChartTag := resolveOciChart(chart)
-		helmArgs = []string{"pull", ociChartURL, "--version", ociChartTag, "--destination", path, "--untar"}
+		ociChartURL, _ := resolveOciChart(chart)
+		helmArgs = []string{"pull", ociChartURL, "--destination", path, "--untar"}
 		helmArgs = append(helmArgs, flags...)
 	} else {
 		helmArgs = []string{"chart", "pull", chart}
