@@ -4,9 +4,13 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"slices"
+	"sort"
 	"strconv"
+	"strings"
 
 	"github.com/helmfile/chartify"
+	"helm.sh/helm/v3/pkg/storage/driver"
 
 	"github.com/helmfile/helmfile/pkg/helmexec"
 	"github.com/helmfile/helmfile/pkg/remote"
@@ -26,6 +30,54 @@ func (st *HelmState) appendHelmXFlags(flags []string, release *ReleaseSpec) []st
 	return flags
 }
 
+func formatLabels(labels map[string]string) string {
+	var labelsList, keys []string
+	for k := range labels {
+		if k == "" || slices.Contains(driver.GetSystemLabels(), k) {
+			continue
+		}
+
+		keys = append(keys, k)
+	}
+	sort.Strings(keys)
+
+	if len(keys) == 0 {
+		return ""
+	}
+
+	for _, k := range keys {
+		val := labels[k]
+		labelsList = append(labelsList, fmt.Sprintf("%s=%s", k, val))
+	}
+	return strings.Join(labelsList, ",")
+}
+
+// append labels flags to helm flags, starting from helm v3.13.0
+func (st *HelmState) appendLabelsFlags(flags []string, helm helmexec.Interface, release *ReleaseSpec, syncReleaseLabels bool) []string {
+	if !helm.IsVersionAtLeast("3.13.0") {
+		return flags
+	}
+	isSyncReleaseLabels := false
+	switch {
+	// Check if SyncReleaseLabels is true in the release spec.
+	case release.SyncReleaseLabels != nil && *release.SyncReleaseLabels:
+		isSyncReleaseLabels = true
+	// Check if syncReleaseLabels argument is true.
+	case syncReleaseLabels:
+		isSyncReleaseLabels = true
+	// Check if SyncReleaseLabels is true in HelmDefaults.
+	case st.HelmDefaults.SyncReleaseLabels != nil && *st.HelmDefaults.SyncReleaseLabels:
+		isSyncReleaseLabels = true
+	}
+	if isSyncReleaseLabels {
+		labels := formatLabels(release.Labels)
+		if labels != "" {
+			flags = append(flags, "--labels", labels)
+		}
+	}
+	return flags
+}
+
 // append post-renderer flags to helm flags
 func (st *HelmState) appendPostRenderFlags(flags []string, release *ReleaseSpec, postRenderer string) []string {
 	switch {
@@ -166,13 +218,17 @@ func (st *HelmState) appendHideNotesFlags(flags []string, helm helmexec.Interfac
 }
 
 // append take-ownership flags to helm flags
-func (st *HelmState) appendTakeOwnershipFlags(flags []string, helm helmexec.Interface, ops *SyncOpts) []string {
+func (st *HelmState) appendTakeOwnershipFlagsForUpgrade(flags []string, helm helmexec.Interface, release *ReleaseSpec, takeOwnership bool) []string {
 	// see https://github.com/helm/helm/releases/tag/v3.17.0
 	if !helm.IsVersionAtLeast("3.17.0") {
 		return flags
 	}
 	switch {
-	case ops.TakeOwnership:
+	case release.TakeOwnership != nil && *release.TakeOwnership:
+		flags = append(flags, "--take-ownership")
+	case takeOwnership:
+		flags = append(flags, "--take-ownership")
+	case st.HelmDefaults.TakeOwnership != nil && *st.HelmDefaults.TakeOwnership:
 		flags = append(flags, "--take-ownership")
 	}
 	return flags
