@@ -24,7 +24,7 @@ func TestGenerateID(t *testing.T) {
 
 			got, err := generateValuesID(&tc.release, tc.data)
 			if err != nil {
-				t.Fatalf("uenxpected error: %v", err)
+				t.Fatalf("unexpected error: %v", err)
 			}
 
 			if d := cmp.Diff(tc.want, got); d != "" {
@@ -38,39 +38,39 @@ func TestGenerateID(t *testing.T) {
 	run(testcase{
 		subject: "baseline",
 		release: ReleaseSpec{Name: "foo", Chart: "incubator/raw"},
-		want:    "foo-values-669d45cd7b",
+		want:    "foo-values-57ff559cd5",
 	})
 
 	run(testcase{
 		subject: "different bytes content",
 		release: ReleaseSpec{Name: "foo", Chart: "incubator/raw"},
 		data:    []byte(`{"k":"v"}`),
-		want:    "foo-values-67d8c67fcf",
+		want:    "foo-values-75cd785b8b",
 	})
 
 	run(testcase{
 		subject: "different map content",
 		release: ReleaseSpec{Name: "foo", Chart: "incubator/raw"},
 		data:    map[string]any{"k": "v"},
-		want:    "foo-values-b9bc64677",
+		want:    "foo-values-5b44fdc768",
 	})
 
 	run(testcase{
 		subject: "different chart",
 		release: ReleaseSpec{Name: "foo", Chart: "stable/envoy"},
-		want:    "foo-values-585c4565f5",
+		want:    "foo-values-6ddb5db94d",
 	})
 
 	run(testcase{
 		subject: "different name",
 		release: ReleaseSpec{Name: "bar", Chart: "incubator/raw"},
-		want:    "bar-values-c94846459",
+		want:    "bar-values-79bbb8df74",
 	})
 
 	run(testcase{
 		subject: "specific ns",
 		release: ReleaseSpec{Name: "foo", Chart: "incubator/raw", Namespace: "myns"},
-		want:    "myns-foo-values-798d69477",
+		want:    "myns-foo-values-c9457ccfb",
 	})
 
 	for id, n := range ids {
